@@ -8,6 +8,8 @@ from collections.abc import Sequence as AbcSequence
 import numpy as np
 import matplotlib.pyplot as pt
 
+logger = logging.getLogger(__name__)
+
 MockDataEntry = Union[float, complex, Sequence[float]]
 
 @dataclass
@@ -40,6 +42,9 @@ def _freq2Hz(freq_uint32):
     return freq
 
 def float2int16array(value):
+    # TODO: check on float < -1.0 or > +1.0
+    # Scale to 16 bit value, but store in 32 bit to avoid
+    # overflow on later operations.
     return np.array(value*2**15, dtype=np.int32)
 
 def _i16(value):
@@ -171,7 +176,7 @@ class Renderer:
         self._render(wait_after)
 
     def _error(self, msg):
-        logging.error(f'{self.name}: {msg}')
+        logger.error(f'{self.name}: {msg}')
         self.errors.add(msg)
 
     def _update_settings(self):
@@ -195,12 +200,15 @@ class Renderer:
             if len(msg) > 0:
                 self._trace('Update: ' + '; '.join(msg))
 
-        if new.relative_phase is not None:
-            self.relative_phase = new.relative_phase
-            new.relative_phase = None
         if new.reset_phase:
             self.nco_phase_offset = (-self.time * self.nco_frequency * 1e-9) % 1
             new.reset_phase = False
+            # reset also resets the 2 other phase registers.
+            self.relative_phase = 0.0
+            self.delta_phase = 0.0
+        if new.relative_phase is not None:
+            self.relative_phase = new.relative_phase
+            new.relative_phase = None
         if new.frequency is not None:
             phase = (self.nco_phase_offset + self.time * self.nco_frequency * 1e-9) % 1
             new_phase_offset = phase - (self.time * new.frequency * 1e-9) % 1
@@ -214,7 +222,7 @@ class Renderer:
 
     def _render(self, time):
         if time & 0x0003:
-            logging.error(f'{self.name}: wait time not aligned on '
+            logger.error(f'{self.name}: wait time not aligned on '
                           f'4 ns boundary: {time} ns (offset={time&0x03} ns)')
             self._error('TIME NOT ALIGNED')
 
